@@ -4,7 +4,8 @@
 #include <QObject>
 #include <QSqlDatabase>
 
-class Database : public QObject {
+class Database : public QObject
+{
     Q_OBJECT
 
 public:
@@ -18,15 +19,21 @@ public slots:
     bool setYouTubeAccessToken(const QString &token);
     bool setDailymotionUsername(const QString &user);
     bool setDailymotionAccessToken(const QString &token, const QString &refresh);
+    bool setVimeoUsername(const QString &user);
+    bool setVimeoAccessToken(const QString &token, const QString &secret);
 
 signals:
+    void error(const QString &errorString);
     void gotYouTubeAccount(const QString &user, const QString &token, const QString &refresh);
     void gotDailymotionAccount(const QString &user, const QString &token, const QString &refresh);
-    void databaseError();
+    void gotVimeoAccount(const QString &user, const QString &token, const QString &secret);
 
 private:
     void restoreYouTubeAccount();
     void restoreDailymotionAccount();
+    void restoreVimeoAccount();
+    void restoreFacebookAccount();
+    void restoreTwitterAccount();
 
 private:
     QSqlDatabase m_database;
